@@ -374,11 +374,11 @@ class SymProcessor:
         header = \
             """from collections import OrderedDict  # NOQA
 
-from numpy import nan, pi, sin, cos, tan, sqrt, exp, select  # NOQA
-from numpy import greater_equal, less_equal, greater, less   # NOQA
-from numpy import logical_and, logical_or, logical_not  # NOQA
-from numpy import array, real, imag, conj, angle, radians  # NOQA
-from numpy import arcsin, arccos, arctan  # NOQA
+from numpy import nan, pi, sin, cos, tan, sqrt, exp, select         # NOQA
+from numpy import greater_equal, less_equal, greater, less, equal   # NOQA
+from numpy import logical_and, logical_or, logical_not              # NOQA
+from numpy import array, real, imag, conj, angle, radians           # NOQA
+from numpy import arcsin, arccos, arctan, arctan2                   # NOQA
 from numpy import log  # NOQA
 
 from andes.core.npfunc import *  # NOQA
