@@ -13,9 +13,10 @@ logger = logging.getLogger(__name__)
 
 class BusFreq(ModelData, Model):
     """
-    Bus frequency measurement.
+    Bus frequency measurement. Outputs frequency in per unit value.
 
-    Bus frequency output variable is `f`.
+    The bus frequency output variable is `f`.
+    The frequency deviation variable is `WO_y`.
     """
     def __init__(self, system, config):
         ModelData.__init__(self)
@@ -25,12 +26,22 @@ class BusFreq(ModelData, Model):
 
         # Parameters
         self.bus = IdxParam(info="bus idx", mandatory=True)
-        self.Tf = NumParam(default=0.02, info="input digital filter time const", unit="sec",
-                           tex_name='T_f')
-        self.Tw = NumParam(default=0.02, info="washout time const", unit="sec",
-                           tex_name='T_w')
-        self.fn = NumParam(default=60.0, info="nominal frequency", unit='Hz',
-                           tex_name='f_n')
+
+        self.Tf = NumParam(default=0.02,
+                           info="input digital filter time const",
+                           unit="sec",
+                           tex_name='T_f',
+                           )
+        self.Tw = NumParam(default=0.02,
+                           info="washout time const",
+                           unit="sec",
+                           tex_name='T_w',
+                           )
+        self.fn = NumParam(default=60.0,
+                           info="nominal frequency",
+                           unit='Hz',
+                           tex_name='f_n',
+                           )
 
         # Variables
         self.iwn = ConstService(v_str='u / (2 * pi * fn)', tex_name=r'1/\omega_n')
